@@ -113,7 +113,7 @@ class ArkoWrapper(Generic[T]):
         def generate() -> Iterator[Union[T, E]]:
             yield from self._tee()
             if not isinstance(other, str) and isinstance(other, Iterable):
-                yield from tee(other)[0]
+                yield from other  # todo:复制生成器
             else:
                 yield other
 
@@ -124,7 +124,7 @@ class ArkoWrapper(Generic[T]):
 
         def generate() -> Iterator[Union[T, E]]:
             if not isinstance(other, str) and isinstance(other, Iterable):
-                yield from tee(other)[0]
+                yield from other  # todo:复制生成器
             else:
                 yield other
             yield from self._tee()
@@ -159,7 +159,7 @@ class ArkoWrapper(Generic[T]):
                 return self.__root__[index]
             try:
                 return self.slice(
-                    *filter(None, [index.start, index.stop, index.step])
+                    start=index.start, stop=index.stop, step=index.step
                 )
             except ValueError:
                 return self.__class__(list(self._max_gen()).__getitem__(index))
@@ -307,6 +307,23 @@ class ArkoWrapper(Generic[T]):
         except StopIteration:
             return False
 
+    def append(self: Wrapper, obj: E) -> Wrapper:
+        """将对象附加到 ArkoWrapper 的末尾。注：此方法会修改本身的 __root__"""
+
+        def clean() -> list[Union[E, T]]:
+            temp = []
+            iter_values = iter(self._tee())
+            try:
+                for _ in range(self._max):
+                    temp.append(next(iter_values))
+            except StopIteration:
+                temp.append(obj)
+                return temp
+
+        result = self.__class__()
+        self.__root__, result.__root__ = tee(clean())
+        return self
+
     def chain(self: Wrapper, *iterables: Iterable[E]) -> Wrapper:
         """创建一个迭代器，它首先返回第一个可迭代对象中所有元素，接着返回下一个可迭代对象中所有元素，直到耗尽所有可迭代对象中的元素。"""
         return self.__class__(chain(self._tee(), *iterables))
@@ -353,6 +370,16 @@ class ArkoWrapper(Generic[T]):
 
         return self.__class__(generator())
 
+    def extend(self: Wrapper, iterable: Iterable[E]) -> Wrapper:
+        if not isinstance(iterable, Iterable):
+            raise TypeError(f"{type(iterable)} object is not iterable")
+
+        def generator() -> Iterator[Union[T, E]]:
+            yield from self._tee()
+            yield from iterable
+
+        return self.__class__(generator())
+
     def fill(
             self: Wrapper,
             num: int,
@@ -422,8 +449,16 @@ class ArkoWrapper(Generic[T]):
             ...
         return result
 
-    def map(self: Wrapper, func: Callable) -> "Wrapper":
-        return self.__class__(map(func, self._tee()))
+    def map(
+            self: Wrapper, func: Callable, start: Optional[int] = 0
+    ) -> "Wrapper":
+        def generator() -> Iterator[T]:
+            iter_values = iter(self._tee())
+            for _ in range(start):
+                next(iter_values)
+            yield from iter_values
+
+        return self.__class__(map(func, generator()))
 
     def mutate(
             self: Wrapper, func: Callable[[Iterable[T], ...], Iterable] = list,
@@ -527,7 +562,7 @@ class ArkoWrapper(Generic[T]):
         ...
 
     def slice(self: Wrapper, *args, **kwargs) -> "Wrapper":
-        return self.__class__(islice(self._tee(), *args, **kwargs))
+        return self.__class__(islice(self._tee(), *args, *kwargs.values()))
 
     def search(self, sub: Sized) -> Generator:
         target = self.tee()
@@ -589,7 +624,7 @@ class ArkoWrapper(Generic[T]):
             self: Wrapper, *iterables: Iterable[E],
             strict: Optional[bool] = False
     ) -> Wrapper:
-        if sys.version_info >= (3, 10):  # pragma: no cover
+        if sys.version_info >= (3, 10):
             return self.__class__(zip(self._tee(), *iterables, strict=strict))
         return self.__class__(zip(self._tee(), *iterables))
 
